.. sigc documentation master file, created by
   sphinx-quickstart on Thr Nov 30 12:42:50 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sigc's documentation!
===================================

sigc+ is a python package to build gene signature score for gene expression matrix

.. toctree::
   :caption: Contents:
   :maxdepth: 3

   install
   autodoc
   tutorials

